==> aria2-1.8.3.tar.bz2: aria2-1.8.3/src/RequestGroupEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "RequestGroupEntry.h"
#include "RequestGroup.h"
#include "Command.h"
#include "DownloadContext.h"

namespace aria2 {

RequestGroupEntry::RequestGroupEntry(RequestGroup* requestGroup,
                                     Command* nextCommand):
  _requestGroup(requestGroup),
  _nextCommand(nextCommand)
{
  _requestGroup->increaseNumCommand();
}

RequestGroupEntry::~RequestGroupEntry()
{
  _requestGroup->decreaseNumCommand();
  delete _nextCommand;
}

Command* RequestGroupEntry::popNextCommand()
{
  Command* temp = _nextCommand;
  _nextCommand = 0;
  return temp;
}

} // namespace aria2

==> aria2-1.11.1.tar.bz2: aria2-1.11.1/src/RequestGroupEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "RequestGroupEntry.h"
#include "RequestGroup.h"
#include "Command.h"
#include "DownloadContext.h"

namespace aria2 {

RequestGroupEntry::RequestGroupEntry(RequestGroup* requestGroup,
                                     Command* nextCommand):
  requestGroup_(requestGroup),
  nextCommand_(nextCommand)
{
  requestGroup_->increaseNumCommand();
}

RequestGroupEntry::~RequestGroupEntry()
{
  requestGroup_->decreaseNumCommand();
  delete nextCommand_;
}

Command* RequestGroupEntry::popNextCommand()
{
  Command* temp = nextCommand_;
  nextCommand_ = 0;
  return temp;
}

void RequestGroupEntry::pushNextCommand(Command* nextCommand)
{
  delete nextCommand_;
  nextCommand_ = nextCommand;
}

} // namespace aria2
